@@ -296,14 +296,14 @@ static alpm_list_t *chk_filedifference(alpm_list_t *filesA, alpm_list_t *filesB)
 	return(ret);
 }
 
-/* Adds pmfileconflict_t to a conflicts list. Pass the conflicts list, type (either
- * PM_FILECONFLICT_TARGET or PM_FILECONFLICT_FILESYSTEM), a file string, and either
- * two package names or one package name and NULL. This is a wrapper for former
- * functionality that was done inline.
+/* Adds pmfileconflict_t to a conflicts list. Pass the conflicts list, type
+ * (either PM_FILECONFLICT_TARGET or PM_FILECONFLICT_FILESYSTEM), a file
+ * string, and either two package names or one package name and NULL. This is
+ * a wrapper for former functionality that was done inline.
  */
 static alpm_list_t *add_fileconflict(alpm_list_t *conflicts,
                     pmfileconflicttype_t type, const char *filestr,
-                    const char* name1, const char* name2)
+                    const char *name1, const char *name2)
 {
 	pmfileconflict_t *conflict;
 	MALLOC(conflict, sizeof(pmfileconflict_t), RET_ERR(PM_ERR_MEMORY, NULL));
@@ -334,7 +334,7 @@ void _alpm_fileconflict_free(pmfileconflict_t *conflict)
 	FREE(conflict);
 }
 
-static int dir_belongsto_pkg(char *dirpath, pmpkg_t *pkg)
+static int dir_belongsto_pkg(const char *dirpath, pmpkg_t *pkg)
 {
 	struct dirent *ent = NULL;
 	struct stat sbuf;
@@ -433,7 +433,6 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 
 		/* declarations for second check */
 		struct stat lsbuf, sbuf;
-		char *filestr = NULL;
 
 		/* CHECK 2: check every target against the filesystem */
 		_alpm_log(PM_LOG_DEBUG, "searching for filesystem conflicts: %s\n", p1->name);
@@ -452,7 +451,9 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 		}
 
 		for(j = tmpfiles; j; j = j->next) {
-			filestr = j->data;
+			const char *filestr = j->data, *relative_path;
+			/* have we acted on this conflict? */
+			int resolved_conflict = 0;
 
 			snprintf(path, PATH_MAX, "%s%s", handle->root, filestr);
 
@@ -462,7 +463,7 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 			}
 			stat(path, &sbuf);
 
-			if(path[strlen(path)-1] == '/') {
+			if(path[strlen(path) - 1] == '/') {
 				if(S_ISDIR(lsbuf.st_mode)) {
 					_alpm_log(PM_LOG_DEBUG, "%s is a directory, not a conflict\n", path);
 					continue;
@@ -471,16 +472,22 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 							"%s is a symlink to a dir, hopefully not a conflict\n", path);
 					continue;
 				}
+				/* if we made it to here, we want all subsequent path comparisons to
+				 * not include the trailing slash. This allows things like file ->
+				 * directory replacements. */
+				path[strlen(path) - 1] = '\0';
 			}
-			_alpm_log(PM_LOG_DEBUG, "checking possible conflict: %s\n", path);
 
-			int resolved_conflict = 0; /* have we acted on this conflict? */
+			_alpm_log(PM_LOG_DEBUG, "checking possible conflict: %s\n", path);
+			relative_path = path + strlen(handle->root);
 
 			/* Check remove list (will we remove the conflicting local file?) */
 			for(k = remove; k && !resolved_conflict; k = k->next) {
 				pmpkg_t *rempkg = k->data;
-				if(rempkg && alpm_list_find_str(alpm_pkg_get_files(rempkg), filestr)) {
-					_alpm_log(PM_LOG_DEBUG, "local file will be removed, not a conflict: %s\n", filestr);
+				if(alpm_list_find_str(alpm_pkg_get_files(rempkg), relative_path)) {
+					_alpm_log(PM_LOG_DEBUG,
+							"local file will be removed, not a conflict: %s\n",
+							relative_path);
 					resolved_conflict = 1;
 				}
 			}
@@ -498,8 +505,11 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 					/* skip removal of file, but not add. this will prevent a second
 					 * package from removing the file when it was already installed
 					 * by its new owner (whether the file is in backup array or not */
-					trans->skip_remove = alpm_list_add(trans->skip_remove, strdup(filestr));
-					_alpm_log(PM_LOG_DEBUG, "file changed packages, adding to remove skiplist: %s\n", filestr);
+					trans->skip_remove = alpm_list_add(trans->skip_remove,
+							strdup(filestr));
+					_alpm_log(PM_LOG_DEBUG,
+							"file changed packages, adding to remove skiplist: %s\n",
+							filestr);
 					resolved_conflict = 1;
 				}
 			}
@@ -518,19 +528,19 @@ alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
 
 			if(!resolved_conflict && dbpkg) {
 				char *rpath = calloc(PATH_MAX+1, sizeof(char));
+				const char *relative_rpath;
 				if(!realpath(path, rpath)) {
-					FREE(rpath);
+					free(rpath);
 					continue;
 				}
-				char *filestr = rpath + strlen(handle->root);
-				if(alpm_list_find_str(alpm_pkg_get_files(dbpkg),filestr)) {
+				relative_rpath = rpath + strlen(handle->root);
+				if(alpm_list_find_str(alpm_pkg_get_files(dbpkg), relative_rpath)) {
 					resolved_conflict = 1;
 				}
 				free(rpath);
 			}
 
 			if(!resolved_conflict) {
-				_alpm_log(PM_LOG_DEBUG, "file found in conflict: %s\n", path);
 				conflicts = add_fileconflict(conflicts, PM_FILECONFLICT_FILESYSTEM,
 						path, p1->name, NULL);
 			}
