@@ -37,6 +37,9 @@
 #include <unistd.h>
 #include <limits.h>
 #include <wchar.h>
+#ifdef HAVE_TERMIOS_H
+#include <termios.h> /* tcflush */
+#endif
 
 #include <alpm.h>
 #include <alpm_list.h>
@@ -100,6 +103,18 @@ int needs_root(void)
 	}
 }
 
+/* discard unhandled input on the terminal's input buffer */
+static int flush_term_input(void) {
+#ifdef HAVE_TCFLUSH
+	if(isatty(fileno(stdin))) {
+		return(tcflush(fileno(stdin), TCIFLUSH));
+	}
+#endif
+
+	/* fail silently */
+	return 0;
+}
+
 /* gets the current screen column width */
 int getcols(int def)
 {
@@ -216,8 +231,9 @@ void indentprint(const char *str, int indent)
 		return;
 	}
 
-	/* if we're not a tty, print without indenting */
-	if(cols == 0) {
+	/* if we're not a tty, or our tty is not wide enough that wrapping even makes
+	 * sense, print without indenting */
+	if(cols == 0 || indent > cols) {
 		printf("%s", str);
 		return;
 	}
@@ -450,12 +466,16 @@ void list_display(const char *title, const alpm_list_t *list)
 	if(!list) {
 		printf("%s\n", _("None"));
 	} else {
-		int cols;
-		const int maxcols = getcols(80);
-		for(i = list, cols = len; i; i = alpm_list_next(i)) {
-			char *str = alpm_list_getdata(i);
+		const int maxcols = getcols(0);
+		int cols = len;
+		const char *str = alpm_list_getdata(list);
+		printf("%s", str);
+		cols += string_length(str);
+		for(i = alpm_list_next(list); i; i = alpm_list_next(i)) {
+			const char *str = alpm_list_getdata(i);
 			int s = string_length(str);
-			if(cols + s + 2 >= maxcols) {
+			/* wrap only if we have enough usable column space */
+			if(maxcols > len && cols + s + 2 >= maxcols) {
 				int j;
 				cols = len;
 				printf("\n");
@@ -791,8 +811,9 @@ static int multiselect_parse(char *array, int count, char *response)
 
 int multiselect_question(char *array, int count)
 {
-	char response[64];
+	char *response, *lastchar;
 	FILE *stream;
+	size_t response_len = 64;
 
 	if(config->noconfirm) {
 		stream = stdout;
@@ -801,19 +822,47 @@ int multiselect_question(char *array, int count)
 		stream = stderr;
 	}
 
+	response = malloc(response_len);
+	if(!response) {
+		return -1;
+	}
+	lastchar = response + response_len - 1;
+	/* sentinel byte to later see if we filled up the entire string */
+	*lastchar = 1;
+
 	while(1) {
 		memset(array, 1, count);
 
 		fprintf(stream, "\n");
 		fprintf(stream, _("Enter a selection (default=all)"));
 		fprintf(stream,	": ");
+		fflush(stream);
 
 		if(config->noconfirm) {
 			fprintf(stream, "\n");
 			break;
 		}
 
-		if(fgets(response, sizeof(response), stdin)) {
+		flush_term_input();
+
+		if(fgets(response, response_len, stdin)) {
+			const size_t response_incr = 64;
+			/* handle buffer not being large enough to read full line case */
+			while(*lastchar == '\0' && lastchar[-1] != '\n') {
+				response_len += response_incr;
+				response = realloc(response, response_len);
+				if(!response) {
+					return -1;
+				}
+				lastchar = response + response_len - 1;
+				/* sentinel byte */
+				*lastchar = 1;
+				if(fgets(response + response_len - response_incr - 1,
+							response_incr + 1, stdin) == 0) {
+					free(response);
+					return -1;
+				}
+			}
 			strtrim(response);
 			if(strlen(response) > 0) {
 				if(multiselect_parse(array, count, response) == -1) {
@@ -821,9 +870,14 @@ int multiselect_question(char *array, int count)
 					continue;
 				}
 			}
+			break;
+		} else {
+			free(response);
+			return -1;
 		}
-		break;
 	}
+
+	free(response);
 	return(0);
 }
 
@@ -850,6 +904,8 @@ int select_question(int count)
 			break;
 		}
 
+		flush_term_input();
+
 		if(fgets(response, sizeof(response), stdin)) {
 			strtrim(response);
 			if(strlen(response) > 0) {
@@ -897,6 +953,8 @@ static int question(short preset, char *fmt, va_list args)
 	}
 
 	fflush(stream);
+	flush_term_input();
+
 	if(fgets(response, sizeof(response), stdin)) {
 		strtrim(response);
 		if(strlen(response) == 0) {
